@@ -41,15 +41,12 @@ LocalIndexedProblem::LocalIndexedProblem(const ProblemPointer& problem, const To
 {
     ENSURE_CHAIN_READ_LOCKED
     // ensure child problems are properly serialized before we serialize the parent problem
-    if (static_cast<uint>(problem->m_diagnostics.size()) != problem->d_func()->diagnosticsSize()) {
-        // see below, the diagnostic size is kept in sync by the mutable API of Problem
-        Q_ASSERT(!problem->diagnostics().isEmpty());
-        // the const cast is ugly but we don't really "change" the state as observed from the outside
-        auto& serialized = const_cast<Problem*>(problem.data())->d_func_dynamic()->diagnosticsList();
-        Q_ASSERT(serialized.isEmpty());
-        foreach(const ProblemPointer& child, problem->m_diagnostics) {
-            serialized << LocalIndexedProblem(child, top);
-        }
+    // see below, the diagnostic size is kept in sync by the mutable API of Problem
+    // the const cast is ugly but we don't really "change" the state as observed from the outside
+    auto& serialized = const_cast<Problem*>(problem.data())->d_func_dynamic()->diagnosticsList();
+    serialized.clear();
+    foreach(const ProblemPointer& child, problem->m_diagnostics) {
+        serialized << LocalIndexedProblem(child, top);
     }
 
     if (!m_index) {
@@ -193,6 +190,8 @@ void Problem::setSeverity(Severity severity)
 QString Problem::severityString() const
 {
     switch(severity()) {
+        case IProblem::NoSeverity:
+            return {};
         case IProblem::Error:
             return i18n("Error");
         case IProblem::Warning:
@@ -269,6 +268,10 @@ QDebug operator<<(QDebug s, const Problem& problem)
 
 QDebug operator<<(QDebug s, const ProblemPointer& problem)
 {
-    s.nospace() << problem->toString();
+    if (!problem) {
+        s.nospace() << "<invalid problem>";
+    } else {
+        s.nospace() << problem->toString();
+    }
     return s.space();
 }
