@@ -726,7 +726,6 @@ struct TopDUContext::ApplyAliasesBuddyInfo {
       m_predecessor = 0;
   }
 
-  //May also be called when this is zero.
   bool alreadyImporting(IndexedQualifiedIdentifier id) {
     ApplyAliasesBuddyInfo* current = this;
     while(current) {
@@ -809,7 +808,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
             continue;
           }
 
-          if(buddy->alreadyImporting( importIdentifier ))
+          if(buddy && buddy->alreadyImporting( importIdentifier ))
             continue; //This import has already been applied to this search
 
           ApplyAliasesBuddyInfo info(1, buddy, importIdentifier);
@@ -885,7 +884,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
             continue;
           }
 
-          if(buddy->alreadyImporting( importIdentifier ))
+          if(buddy && buddy->alreadyImporting( importIdentifier ))
             continue; //This import has already been applied to this search
 
           ApplyAliasesBuddyInfo info(2, buddy, importIdentifier);
@@ -1112,7 +1111,11 @@ int TopDUContext::indexForUsedDeclaration(Declaration* declaration, bool create)
     return (int)(index | (1<<31)); //We don't put context-local declarations into the list, that's a waste. We just use the mark them with the highest bit.
   }
 
-  DeclarationId id(declaration->id());
+  // if the declaration can not be found from this top-context, we create a direct
+  // reference by index, to ensure that the use can be resolved in
+  // usedDeclarationForIndex
+  bool useDirectId = !recursiveImportIndices().contains(declaration->topContext());
+  DeclarationId id(declaration->id(useDirectId));
 
   int index = -1;
 
