@@ -43,7 +43,7 @@ public:
   /// Copy constructor. \param rhs type to copy
   ReferenceType (const ReferenceType& rhs);
   /// Constructor using raw data. \param data internal data.
-  ReferenceType(ReferenceTypeData& data);
+  explicit ReferenceType(ReferenceTypeData& data);
   /// Destructor
   virtual ~ReferenceType();
 
@@ -75,17 +75,17 @@ public:
    */
   void setIsRValue(bool isRValue);
 
-  virtual QString toString() const;
+  virtual QString toString() const override;
 
-  virtual uint hash() const;
+  virtual uint hash() const override;
 
-  virtual WhichType whichType() const;
+  virtual WhichType whichType() const override;
 
-  virtual AbstractType* clone() const;
+  virtual AbstractType* clone() const override;
 
-  virtual bool equals(const AbstractType* rhs) const;
+  virtual bool equals(const AbstractType* rhs) const override;
 
-  virtual void exchangeTypes( TypeExchanger* exchanger );
+  virtual void exchangeTypes( TypeExchanger* exchanger ) override;
 
   enum {
     Identity = 4
@@ -94,7 +94,7 @@ public:
   typedef ReferenceTypeData Data;
 
 protected:
-  virtual void accept0 (TypeVisitor *v) const;
+  virtual void accept0 (TypeVisitor *v) const override;
 
   TYPE_DECLARE_DATA(ReferenceType)
 };
@@ -110,5 +110,3 @@ inline ReferenceType* fastCast<ReferenceType*>(AbstractType* from) {
 }
 
 #endif // KDEVPLATFORM_TYPESYSTEM_H
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
