@@ -1,4 +1,4 @@
-/* 
+/*
    Copyright 2007 David Nolden <david.nolden.kdevelop@art-master.de>
 
    This library is free software; you can redistribute it and/or
@@ -18,7 +18,11 @@
 
 #include "includeitem.h"
 
-namespace KDevelop {
+#include <QDebug>
+
+#include <util/path.h>
+
+using namespace KDevelop;
 
 IncludeItem::IncludeItem()
     : pathNumber(0)
@@ -27,16 +31,19 @@ IncludeItem::IncludeItem()
 }
 
 ///Constructs the url from basePath and name.
-KUrl IncludeItem::url() const
+// TODO: port this to Path
+QUrl IncludeItem::url() const
 {
-  KUrl u;
+  QUrl u;
   if( !basePath.isEmpty() ) {
-    u = KUrl( basePath );
-    u.addPath( name );
+    u = Path(Path(basePath), name ).toUrl();
   }else{
-    u = KUrl( name );
+    u = QUrl::fromLocalFile( name );
   }
   return u;
 }
 
+QDebug operator<<(QDebug dbg, const IncludeItem& item)
+{
+    return dbg << item.url();
 }
