@@ -29,6 +29,12 @@
 
 namespace KDevelop
 {
+void initializeFilteredItem(FilteredItem& item, const ErrorFormat& filter, const QRegularExpressionMatch& match)
+{
+    item.lineNo = match.captured( filter.lineGroup ).toInt() - 1;
+    item.columnNo = filter.columnNumber(match);
+}
+
 
 template<typename ErrorFormats>
 FilteredItem match(const ErrorFormats& errorFormats, const QString& line)
@@ -37,15 +43,8 @@ FilteredItem match(const ErrorFormats& errorFormats, const QString& line)
     for( const ErrorFormat& curErrFilter : errorFormats ) {
         const auto match = curErrFilter.expression.match(line);
         if( match.hasMatch() ) {
+            initializeFilteredItem(item, curErrFilter, match);
             item.url = QUrl::fromUserInput(match.captured( curErrFilter.fileGroup ));
-            item.lineNo = match.captured( curErrFilter.lineGroup ).toInt() - 1;
-            if(curErrFilter.columnGroup >= 0) {
-                item.columnNo = match.captured( curErrFilter.columnGroup ).toInt() - 1;
-            } else {
-                item.columnNo = 0;
-            }
-
-            QString txt = match.captured(curErrFilter.textGroup);
 
             item.type = FilteredItem::ErrorItem;
 
@@ -92,7 +91,6 @@ struct CompilerFilterStrategyPrivate
     PositionMap m_positionInCurrentDirs;
 };
 
-
 CompilerFilterStrategyPrivate::CompilerFilterStrategyPrivate(const QUrl& buildDir)
     : m_buildDir(buildDir)
 {
@@ -261,6 +259,8 @@ FilteredItem CompilerFilterStrategy::errorInLine(const QString& line)
 #endif
         // GCC - another case, eg. for #include "pixmap.xpm" which does not exists
         ErrorFormat( QStringLiteral("^([^:\t]+):([0-9]+):([0-9]+):([^0-9]+)"), 1, 2, 4, 3 ),
+        // ant
+        ErrorFormat("\\[javac\\][\\s]+([^:\t]+):([0-9]+): (warning: .*|error: .*)", 1, 2, 3, "javac"),
         // GCC
         ErrorFormat( QStringLiteral("^([^:\t]+):([0-9]+):([^0-9]+)"), 1, 2, 3 ),
         // GCC
@@ -313,14 +313,9 @@ FilteredItem CompilerFilterStrategy::errorInLine(const QString& line)
                 }
                 item.url = d->pathForFile( match.captured( curErrFilter.fileGroup ) ).toUrl();
             }
-            item.lineNo = match.captured( curErrFilter.lineGroup ).toInt() - 1;
-            if(curErrFilter.columnGroup >= 0) {
-                item.columnNo = match.captured( curErrFilter.columnGroup ).toInt() - 1;
-            } else {
-                item.columnNo = 0;
-            }
+            initializeFilteredItem(item, curErrFilter, match);
 
-            QString txt = match.captured(curErrFilter.textGroup);
+            const QString txt = match.captured(curErrFilter.textGroup);
 
             // Find the indicator which happens most early.
             int earliestIndicatorIdx = txt.length();
