@@ -36,6 +36,7 @@
 #include <KPluginFactory>
 #include <KRun>
 #include <KService>
+#include <KOpenWithDialog>
 
 #include <interfaces/contextmenuextension.h>
 #include <interfaces/context.h>
@@ -60,7 +61,7 @@ bool sortActions(QAction* left, QAction* right)
 
 bool isTextEditor(const KService::Ptr& service)
 {
-    return service->serviceTypes().contains( "KTextEditor/Document" );
+    return service->serviceTypes().contains( QStringLiteral("KTextEditor/Document") );
 }
 
 QString defaultForMimeType(const QString& mimeType)
@@ -77,7 +78,7 @@ QString defaultForMimeType(const QString& mimeType)
 
 bool canOpenDefault(const QString& mimeType)
 {
-    if (defaultForMimeType(mimeType).isEmpty() && mimeType == "inode/directory") {
+    if (defaultForMimeType(mimeType).isEmpty() && mimeType == QLatin1String("inode/directory")) {
         // potentially happens in non-kde environments apparently, see https://git.reviewboard.kde.org/r/122373
         return KMimeTypeTrader::self()->preferredService(mimeType);
     } else {
@@ -87,7 +88,7 @@ bool canOpenDefault(const QString& mimeType)
 }
 
 OpenWithPlugin::OpenWithPlugin ( QObject* parent, const QVariantList& )
-    : IPlugin ( "kdevopenwith", parent ),
+    : IPlugin ( QStringLiteral("kdevopenwith"), parent ),
     m_actionMap( 0 )
 {
     KDEV_USE_EXTENSION_INTERFACE( IOpenWith )
@@ -114,7 +115,7 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension( KDevelop::C
         m_urls = filectx->urls();
     } else if ( projctx && projctx->items().count() > 0 ) {
         // For now, let's handle *either* files only *or* directories only
-        const int wantedType = projctx->items().first()->type();
+        const int wantedType = projctx->items().at(0)->type();
         foreach( ProjectBaseItem* item, projctx->items() ) {
             if (wantedType == ProjectBaseItem::File && item->file()) {
                 m_urls << item->file()->path().toUrl();
@@ -136,8 +137,8 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension( KDevelop::C
     QMimeType mimetype = QMimeDatabase().mimeTypeForUrl(m_urls.first());
     m_mimeType = mimetype.name();
 
-    QList<QAction*> partActions = actionsForServiceType("KParts/ReadOnlyPart");
-    QList<QAction*> appActions = actionsForServiceType("Application");
+    QList<QAction*> partActions = actionsForServiceType(QStringLiteral("KParts/ReadOnlyPart"));
+    QList<QAction*> appActions = actionsForServiceType(QStringLiteral("Application"));
 
     OpenWithContext subContext(m_urls, mimetype);
     QList<ContextMenuExtension> extensions = ICore::self()->pluginController()->queryPluginsForContextMenuExtensions( &subContext );
@@ -146,9 +147,21 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension( KDevelop::C
         partActions += ext.actions(ContextMenuExtension::OpenEmbeddedGroup);
     }
 
+    {
+        auto other = new QAction(i18n("other..."), this);
+        connect(other, &QAction::triggered, this, [this] {
+            auto dialog = new KOpenWithDialog(m_urls, ICore::self()->uiController()->activeMainWindow());
+            if (dialog->exec() == QDialog::Accepted && dialog->service()) {
+                openService(dialog->service());
+            }
+        });
+        appActions << other;
+    }
+
     // Now setup a menu with actions for each part and app
     QMenu* menu = new QMenu( i18n("Open With" ) );
-    menu->setIcon( QIcon::fromTheme( "document-open" ) );
+    auto documentOpenIcon = QIcon::fromTheme( QStringLiteral("document-open") );
+    menu->setIcon( documentOpenIcon );
 
     if (!partActions.isEmpty()) {
         menu->addSection(i18n("Embedded Editors"));
@@ -163,16 +176,12 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension( KDevelop::C
 
     if (canOpenDefault(m_mimeType)) {
         QAction* openAction = new QAction( i18n( "Open" ), this );
-        openAction->setIcon( QIcon::fromTheme( "document-open" ) );
+        openAction->setIcon( documentOpenIcon );
         connect( openAction, SIGNAL(triggered()), SLOT(openDefault()) );
         ext.addAction( KDevelop::ContextMenuExtension::FileGroup, openAction );
     }
 
-    if (!menu->isEmpty()) {
-        ext.addAction(KDevelop::ContextMenuExtension::FileGroup, menu->menuAction());
-    } else {
-        delete menu;
-    }
+    ext.addAction(KDevelop::ContextMenuExtension::FileGroup, menu->menuAction());
     return ext;
 }
 
@@ -220,7 +229,7 @@ void OpenWithPlugin::openDefault()
     }
 
     // default handlers
-    if (m_mimeType == "inode/directory") {
+    if (m_mimeType == QLatin1String("inode/directory")) {
         KService::Ptr service = KMimeTypeTrader::self()->preferredService(m_mimeType);
         KRun::runService(*service, m_urls, ICore::self()->uiController()->activeMainWindow());
     } else {
@@ -232,16 +241,20 @@ void OpenWithPlugin::openDefault()
 
 void OpenWithPlugin::open( const QString& storageid )
 {
-    KService::Ptr svc = KService::serviceByStorageId( storageid );
-    if( svc->isApplication() ) {
-        KRun::runService( *svc, m_urls, ICore::self()->uiController()->activeMainWindow() );
+    openService(KService::serviceByStorageId( storageid ));
+}
+
+void OpenWithPlugin::openService(const KService::Ptr& service)
+{
+    if (service->isApplication()) {
+        KRun::runService( *service, m_urls, ICore::self()->uiController()->activeMainWindow() );
     } else {
-        QString prefName = svc->desktopEntryName();
-        if ( isTextEditor(svc) ) {
+        QString prefName = service->desktopEntryName();
+        if (isTextEditor(service)) {
             // If the user chose a KTE part, lets make sure we're creating a TextDocument instead of
             // a PartDocument by passing no preferredpart to the documentcontroller
             // TODO: Solve this rather inside DocumentController
-            prefName = "";
+            prefName.clear();
         }
         foreach( const QUrl& u, m_urls ) {
             ICore::self()->documentController()->openDocument( u, prefName );
@@ -249,17 +262,17 @@ void OpenWithPlugin::open( const QString& storageid )
     }
 
     KConfigGroup config = KSharedConfig::openConfig()->group("Open With Defaults");
-    if (storageid != config.readEntry(m_mimeType, QString())) {
+    if (service->storageId() != config.readEntry(m_mimeType, QString())) {
         int setDefault = KMessageBox::questionYesNo(
             qApp->activeWindow(),
             i18nc("%1: mime type name, %2: app/part name", "Do you want to open all '%1' files by default with %2?",
-                 m_mimeType, svc->name() ),
+                 m_mimeType, service->name() ),
             i18n("Set as default?"),
             KStandardGuiItem::yes(), KStandardGuiItem::no(),
             QStringLiteral("OpenWith-%1").arg(m_mimeType)
         );
         if (setDefault == KMessageBox::Yes) {
-            config.writeEntry(m_mimeType, storageid);
+            config.writeEntry(m_mimeType, service->storageId());
         }
     }
 }
