@@ -31,7 +31,6 @@ class IDocument;
 class DUContext;
 class TopDUContext;
 class Declaration;
-class ParseJob;
 }
 
 class OutlineModel : public QAbstractItemModel
@@ -39,7 +38,7 @@ class OutlineModel : public QAbstractItemModel
     Q_OBJECT
     Q_DISABLE_COPY(OutlineModel)
 public:
-    explicit OutlineModel(QObject* parent = 0);
+    explicit OutlineModel(QObject* parent = nullptr);
     ~OutlineModel() override;
 
     QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
@@ -53,7 +52,6 @@ public:
 public slots:
     void activate(const QModelIndex& realIndex);
 private slots:
-    void onParseJobFinished(KDevelop::ParseJob* job);
     void rebuildOutline(KDevelop::IDocument* doc);
 private:
     std::unique_ptr<OutlineNode> m_rootNode;
