@@ -48,7 +48,7 @@ class PatchHighlighter : public QObject
     Q_OBJECT
 public:
     PatchHighlighter( Diff2::DiffModel* model, KDevelop::IDocument* doc, PatchReviewPlugin* plugin ) throw( QString );
-    ~PatchHighlighter();
+    ~PatchHighlighter() override;
     KDevelop::IDocument* doc();
     QList< KTextEditor::MovingRange* > ranges() const;
 private slots:
