@@ -80,9 +80,11 @@ public slots:
 
 private:
     void setFileInfo( QStandardItem *item, unsigned int hunksNum ) {
-        QString newText = i18ncp( "%1: number of changed hunks, %2: file name",
+        const auto url = item->index().data(VcsFileChangesModel::UrlRole).toUrl();
+        const QString path = ICore::self()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain);
+        const QString newText = i18ncp( "%1: number of changed hunks, %2: file name",
             "%2 (1 hunk)", "%2 (%1 hunks)", hunksNum,
-            item->index().data(VcsFileChangesModel::UrlRole).toUrl().toDisplayString(QUrl::PreferLocalFile) );
+            path);
         item->setText( newText );
     }
 };
@@ -202,7 +204,11 @@ void PatchReviewToolView::showEditDialog() {
 
     bool allowSelection = m_plugin->patch() && m_plugin->patch()->canSelectFiles();
     m_fileModel = new PatchFilesModel( this, allowSelection );
-    m_editPatch.filesList->setModel( m_fileModel );
+    m_fileSortProxyModel = new VcsFileChangesSortProxyModel(this);
+    m_fileSortProxyModel->setSourceModel(m_fileModel);
+    m_fileSortProxyModel->sort(1);
+    m_fileSortProxyModel->setDynamicSortFilter(true);
+    m_editPatch.filesList->setModel( m_fileSortProxyModel );
     m_editPatch.filesList->header()->hide();
     m_editPatch.filesList->setRootIsDecorated( false );
     m_editPatch.filesList->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -384,7 +390,7 @@ void PatchReviewToolView::fileItemChanged( QStandardItem* item )
     if (item->column()!=0)
         return;
 
-    QUrl url = m_fileModel->statusInfo(item->index()).url();
+    QUrl url = item->index().data(VcsFileChangesModel::UrlRole).toUrl();
     if (url.isEmpty())
         return;
 
@@ -434,10 +440,9 @@ void PatchReviewToolView::finishReview() {
     m_plugin->finishReview( selectedUrls );
 }
 
-void PatchReviewToolView::fileDoubleClicked( const QModelIndex& idx ) {
-    QModelIndex i = idx.sibling(idx.row(), 0);
-    QUrl file = m_fileModel->statusInfo( i ).url();
-
+void PatchReviewToolView::fileDoubleClicked( const QModelIndex& idx )
+{
+    const QUrl file = idx.data(VcsFileChangesModel::UrlRole).toUrl();
     activate( file );
 }
 
@@ -462,8 +467,8 @@ void PatchReviewToolView::kompareModelChanged() {
             if ( diffs )
                 cnt = diffs->count();
 
-            QUrl file = m_plugin->urlForFileModel( *it );
-            if( !QFileInfo( file.toLocalFile() ).isReadable() )
+            const QUrl file = m_plugin->urlForFileModel( *it );
+            if( file.isLocalFile() && !QFileInfo( file.toLocalFile() ).isReadable() )
                 continue;
 
             VcsStatusInfo status;
@@ -499,12 +504,10 @@ void PatchReviewToolView::documentActivated( IDocument* doc ) {
     if ( !m_plugin->modelList() )
         return;
 
-    QModelIndex idx = m_fileModel->indexForUrl( doc->url() );
-    if ( idx.isValid() ) {
-        m_editPatch.filesList->setCurrentIndex( idx );
-    } else {
-        m_editPatch.filesList->setCurrentIndex( QModelIndex() );
-    }
+    const auto matches = m_fileSortProxyModel->match(
+        m_fileSortProxyModel->index(0, 0), VcsFileChangesModel::UrlRole,
+        doc->url(), 1, Qt::MatchExactly);
+    m_editPatch.filesList->setCurrentIndex(matches.value(0));
 }
 
 void PatchReviewToolView::runTests()
