@@ -36,9 +36,7 @@
 #include <interfaces/iuicontroller.h>
 #include <interfaces/idocumentcontroller.h>
 
-#include <language/backgroundparser/parsejob.h>
 #include <interfaces/ilanguagecontroller.h>
-#include <language/backgroundparser/backgroundparser.h>
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchain.h>
 #include <util/kdevstringhandler.h>
@@ -46,6 +44,7 @@
 #include "problemhighlighter.h"
 #include "problemtreeview.h"
 #include "problemreportermodel.h"
+#include "language/assistant/staticassistantsmanager.h"
 #include <interfaces/context.h>
 #include <language/interfaces/editorcontext.h>
 #include <language/duchain/duchainutils.h>
@@ -95,8 +94,10 @@ ProblemReporterPlugin::ProblemReporterPlugin(QObject* parent, const QVariantList
             &ProblemReporterPlugin::documentClosed);
     connect(ICore::self()->documentController(), &IDocumentController::textDocumentCreated, this,
             &ProblemReporterPlugin::textDocumentCreated);
-    connect(ICore::self()->languageController()->backgroundParser(), &BackgroundParser::parseJobFinished, this,
-            &ProblemReporterPlugin::parseJobFinished, Qt::DirectConnection);
+    connect(DUChain::self(), &DUChain::updateReady,
+            this, &ProblemReporterPlugin::updateReady);
+    connect(ICore::self()->languageController()->staticAssistantsManager(), &StaticAssistantsManager::problemsChanged,
+            this, &ProblemReporterPlugin::updateHighlight);
 }
 
 ProblemReporterPlugin::~ProblemReporterPlugin()
@@ -130,7 +131,6 @@ void ProblemReporterPlugin::textDocumentCreated(KDevelop::IDocument* document)
 {
     Q_ASSERT(document->textDocument());
     m_highlighters.insert(IndexedString(document->url()), new ProblemHighlighter(document->textDocument()));
-    DUChainReadLocker lock(DUChain::lock());
     DUChain::self()->updateContextForUrl(IndexedString(document->url()),
                                          KDevelop::TopDUContext::AllDeclarationsContextsAndUses, this);
 }
@@ -138,17 +138,16 @@ void ProblemReporterPlugin::textDocumentCreated(KDevelop::IDocument* document)
 void ProblemReporterPlugin::updateReady(const IndexedString& url, const KDevelop::ReferencedTopDUContext&)
 {
     m_model->problemsUpdated(url);
-    ProblemHighlighter* ph = m_highlighters.value(url);
-    if (ph) {
-        QVector<IProblem::Ptr> allProblems = m_model->problems(url, false);
-        ph->setProblems(allProblems);
-    }
+    updateHighlight(url);
 }
 
-void ProblemReporterPlugin::parseJobFinished(KDevelop::ParseJob* parseJob)
+void ProblemReporterPlugin::updateHighlight(const KDevelop::IndexedString& url)
 {
-    if (parseJob->duChain())
-        updateReady(parseJob->document());
+  ProblemHighlighter* ph = m_highlighters.value(url);
+    if (ph) {
+        auto allProblems = m_model->problems(url, false);
+        ph->setProblems(allProblems);
+    }
 }
 
 KDevelop::ContextMenuExtension ProblemReporterPlugin::contextMenuExtension(KDevelop::Context* context)
