@@ -449,10 +449,9 @@ void ProjectTreeView::keyPressEvent(QKeyEvent* event)
 
 void ProjectTreeView::drawBranches(QPainter* painter, const QRect& rect, const QModelIndex& index) const
 {
-    const bool colorizeByProject = KSharedConfig::openConfig()->group("UiSettings").readEntry("ColorizeByProject", false);
-    if (colorizeByProject) {
+    if (WidgetColorizer::colorizeByProject()) {
         const auto projectPath = index.data(ProjectModel::ProjectRole).value<IProject *>()->path();
-        const QColor color = WidgetColorizer::colorForId(qHash(projectPath), palette());
+        const QColor color = WidgetColorizer::colorForId(qHash(projectPath), palette(), true);
         WidgetColorizer::drawBranches(this, painter, rect, index, color);
     }
 
