@@ -20,7 +20,6 @@
 
 #include "uihelper.h"
 #include "sessionsmodel.h"
-#include "welcomepagedocument.h"
 
 #include <QQmlContext>
 #include <QQmlComponent>
@@ -51,6 +50,7 @@ WelcomePageWidget::WelcomePageWidget(const QList<IProject*> & /*projects*/, QWid
     //setup kdeclarative library
     KDeclarative::KDeclarative kdeclarative;
     kdeclarative.setDeclarativeEngine(engine());
+    kdeclarative.setTranslationDomain("kdevwelcomepage");
     kdeclarative.setupBindings();
 
     setResizeMode(QQuickWidget::SizeRootObjectToView);
@@ -72,13 +72,3 @@ void WelcomePageWidget::areaChanged(Sublime::Area* area)
 {
     rootContext()->setContextProperty(QStringLiteral("area"), area->objectName());
 }
-
-WelcomePageView::WelcomePageView(Sublime::Document* doc, Sublime::View::WidgetOwnership ws)
-    : View(doc, ws)
-{
-}
-
-QWidget* WelcomePageView::createWidget(QWidget* parent)
-{
-    return new WelcomePageWidget(QList<IProject*>(), parent);
-}
