@@ -20,9 +20,12 @@
 
 #include "projectutils.h"
 #include <project/projectmodel.h>
+#include "path.h"
 #include <QMenu>
-#include <KIcon>
-#include <KMenu>
+#include <QIcon>
+
+#include <KLocalizedString>
+
 #include <interfaces/icore.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/context.h>
@@ -31,6 +34,23 @@
 
 namespace KDevelop {
 
+ProjectItemContextImpl::ProjectItemContextImpl(const QList<ProjectBaseItem*>& items)
+    : ProjectItemContext(items)
+{
+}
+
+QList<QUrl> ProjectItemContextImpl::urls() const
+{
+    QList<QUrl> urls;
+    foreach (const auto& item, items()) {
+        const auto url = item->path().toUrl();
+        if (url.isValid()) {
+            urls << url;
+        }
+    }
+    return urls;
+}
+
 class Populator : public QObject
 {
     Q_OBJECT
@@ -40,17 +60,17 @@ public:
     , m_pos(pos)
     , m_text(text)
     {
-        connect(action, SIGNAL(destroyed(QObject*)), SLOT(deleteLater()));
-        connect(action, SIGNAL(triggered(bool)), SLOT(populate()));
+        connect(action, &QAction::destroyed, this, &Populator::deleteLater);
+        connect(action, &QAction::triggered, this, &Populator::populate);
     }
 
 public Q_SLOTS:
     void populate()
     {
-        KMenu* menu = new KMenu(m_text);
-        connect(menu, SIGNAL(aboutToHide()), menu, SLOT(deleteLater()));
-        menu->addAction(KIcon(m_item->iconName()), m_text)->setEnabled(false);
-        ProjectItemContext context(QList< ProjectBaseItem* >() << m_item);
+        QMenu* menu = new QMenu(m_text);
+        connect(menu, &QMenu::aboutToHide, menu, &QMenu::deleteLater);
+        menu->addAction(QIcon::fromTheme(m_item->iconName()), m_text)->setEnabled(false);
+        ProjectItemContextImpl context({m_item});
         QList<ContextMenuExtension> extensions = ICore::self()->pluginController()->queryPluginsForContextMenuExtensions( &context );
         ContextMenuExtension::populateMenu(menu, extensions);
         menu->popup(m_pos);
@@ -71,7 +91,7 @@ void populateParentItemsMenu( ProjectBaseItem* item, QMenu* menu )
     bool hasSeparator = false;
     while(parent)
     {
-        if(!parent->url().isEmpty())
+        if(!parent->path().isValid())
         {
             if(!hasSeparator)
             {
@@ -79,7 +99,7 @@ void populateParentItemsMenu( ProjectBaseItem* item, QMenu* menu )
                 menu->addSeparator();
             }
 
-            QString prettyName = ICore::self()->projectController()->prettyFileName(parent->url(), KDevelop::IProjectController::FormatPlain);
+            QString prettyName = ICore::self()->projectController()->prettyFileName(parent->path().toUrl(), IProjectController::FormatPlain);
 
             QString text;
             if(parent->parent())
@@ -88,7 +108,7 @@ void populateParentItemsMenu( ProjectBaseItem* item, QMenu* menu )
                 text = i18n("Project %1", prettyName);
 
             QAction* action = menu->addAction(text);
-            action->setIcon(KIcon(parent->iconName()));
+            action->setIcon(QIcon::fromTheme(parent->iconName()));
             // The populator will either spawn a menu when the action is triggered, or it will delete itself
             new Populator(parent, action, QCursor::pos(), text);
         }
@@ -97,6 +117,36 @@ void populateParentItemsMenu( ProjectBaseItem* item, QMenu* menu )
     }
 }
 
+QList<ProjectFileItem*> allFiles(ProjectBaseItem* projectItem)
+{
+    QList<ProjectFileItem*> files;
+    if ( ProjectFolderItem * folder = projectItem->folder() )
+    {
+        QList<ProjectFolderItem*> folder_list = folder->folderList();
+        for ( QList<ProjectFolderItem*>::Iterator it = folder_list.begin(); it != folder_list.end(); ++it )
+        {
+            files += allFiles( ( *it ) );
+        }
+
+        QList<ProjectTargetItem*> target_list = folder->targetList();
+        for ( QList<ProjectTargetItem*>::Iterator it = target_list.begin(); it != target_list.end(); ++it )
+        {
+            files += allFiles( ( *it ) );
+        }
+
+        files += folder->fileList();
+    }
+    else if ( ProjectTargetItem * target = projectItem->target() )
+    {
+        files += target->fileList();
+    }
+    else if ( ProjectFileItem * file = projectItem->file() )
+    {
+        files.append( file );
+    }
+    return files;
+}
+
 }
 
 #include "projectutils.moc"
