@@ -248,6 +248,12 @@ IndexedString::IndexedString(const QUrl& url)
     : IndexedString(url.isLocalFile() ? url.toLocalFile() : url.toString())
 {
     Q_ASSERT(url.isEmpty() || !url.isRelative());
+#if !defined(QT_NO_DEBUG)
+    if (url != url.adjusted(QUrl::NormalizePathSegments)) {
+      qWarning() << "wrong url" << url << url.adjusted(QUrl::NormalizePathSegments);
+    }
+#endif
+    Q_ASSERT(url == url.adjusted(QUrl::NormalizePathSegments));
 }
 
 IndexedString::IndexedString(const QString& string)
@@ -335,7 +341,7 @@ const char* IndexedString::c_str() const
     if (!m_index) {
         return 0;
     } else if (isSingleCharIndex(m_index)) {
-#if __BYTE_ORDER == __LITTLE_ENDIAN
+#if Q_BYTE_ORDER == Q_LITTLE_ENDIAN
         const uint offset = 0;
 #else
         const uint offset = 3;
