@@ -39,7 +39,7 @@ class KDEVPLATFORMSHELL_EXPORT EnvironmentConfigureButton : public QPushButton
 {
     Q_OBJECT
 public:
-    explicit EnvironmentConfigureButton(QWidget* parent = 0);
+    explicit EnvironmentConfigureButton(QWidget* parent = nullptr);
     ~EnvironmentConfigureButton() override;
 
     void setSelectionWidget(EnvironmentSelectionWidget* widget);
