@@ -62,6 +62,7 @@
 #include "documentcontroller.h"
 #include "debug.h"
 #include <path.h>
+#include <shellutils.h>
 
 namespace KDevelop {
 
@@ -421,6 +422,10 @@ bool TextDocument::save(DocumentSaveMode mode)
             break;
     }
 
+    if (!KDevelop::ensureWritable(QList<QUrl>() << url())) {
+        return false;
+    }
+
     QUrl urlBeforeSave = d->document->url();
     if (d->document->documentSave())
     {
@@ -479,6 +484,15 @@ KTextEditor::Range TextDocument::textSelection() const
     return PartDocument::textSelection();
 }
 
+QString TextDocument::text(const KTextEditor::Range &range) const
+{
+    if (!d->document) {
+        return QString();
+    }
+
+    return d->document->text( range );
+}
+
 QString TextDocument::textLine() const
 {
     if (!d->document) {
@@ -713,8 +727,8 @@ void KDevelop::TextDocument::populateContextMenu( KTextEditor::View* v, QMenu* m
 
     d->m_addedContextMenu = new QMenu();
 
-    Context* c = new EditorContext( v, v->cursorPosition() );
-    QList<ContextMenuExtension> extensions = Core::self()->pluginController()->queryPluginsForContextMenuExtensions( c );
+    EditorContext c(v, v->cursorPosition());
+    auto extensions = Core::self()->pluginController()->queryPluginsForContextMenuExtensions(&c);
 
     ContextMenuExtension::populateMenu(d->m_addedContextMenu, extensions);
 
