@@ -49,7 +49,6 @@
 #include "partdocument.h"
 #include "textdocument.h"
 #include "documentcontroller.h"
-#include "assistantpopup.h"
 #include <ktexteditor/view.h>
 #include "workingsetcontroller.h"
 #include "workingsets/workingset.h"
@@ -146,8 +145,6 @@ public:
     QPointer<Sublime::MainWindow> activeSublimeWindow;
     bool areasRestored;
 
-    /// Currently shown assistant popup.
-    QPointer<AssistantPopup> currentShownAssistant;
     /// QWidget implementing IToolViewActionListener interface, or null
     QPointer<QWidget> activeActionListener;
     QTimer m_assistantTimer;
@@ -327,7 +324,7 @@ void UiController::raiseToolView(QWidget* toolViewWidget)
     }
 }
 
-void UiController::addToolView(const QString & name, IToolViewFactory *factory)
+void UiController::addToolView(const QString & name, IToolViewFactory *factory, FindFlags state)
 {
     if (!factory)
         return;
@@ -338,7 +335,7 @@ void UiController::addToolView(const QString & name, IToolViewFactory *factory)
 
     /* Until areas are restored, we don't know which views should be really
        added, and which not, so we just record view availability.  */
-    if (d->areasRestored) {
+    if (d->areasRestored && state != None) {
          foreach (Sublime::Area* area, allAreas()) {
              addToolViewToArea(factory, doc, area);
          }
@@ -722,35 +719,6 @@ void UiController::showErrorMessage(const QString& message, int timeout)
     QMetaObject::invokeMethod(mw, "showErrorMessage", Q_ARG(QString, message), Q_ARG(int, timeout));
 }
 
-void UiController::hideAssistant()
-{
-    if (d->currentShownAssistant) {
-        d->currentShownAssistant->hide();
-    }
-}
-
-void UiController::popUpAssistant(const KDevelop::IAssistant::Ptr& assistant)
-{
-    if(!assistant)
-        return;
-
-    Sublime::View* view = d->activeSublimeWindow->activeView();
-    if( !view )
-    {
-        qCDebug(SHELL) << "no active view in mainwindow";
-        return;
-    }
-
-    auto editorView = qobject_cast<KTextEditor::View*>(view->widget());
-    Q_ASSERT(editorView);
-    if (editorView) {
-        if ( !d->currentShownAssistant ) {
-            d->currentShownAssistant = new AssistantPopup;
-        }
-        d->currentShownAssistant->reset(editorView, assistant);
-    }
-}
-
 const QHash< IToolViewFactory*, Sublime::ToolDocument* >& UiController::factoryDocuments() const
 {
     return d->factoryDocuments;
